@@ -3,6 +3,7 @@ from emmet.core.polar import DielectricDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.dielectric.query_operators import DielectricQuery
+from emmet.api.core.global_header import GlobalHeaderProcessor
 
 
 def dielectric_resource(dielectric_store):
@@ -17,6 +18,7 @@ def dielectric_resource(dielectric_store):
                 DielectricDoc, default_fields=["material_id", "last_updated"]
             ),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Dielectric"],
         disable_validation=True,
     )
