@@ -1,5 +1,5 @@
 from maggma.api.resource import ReadOnlyResource
-from emmet.core.elasticity import ElasticityDoc
+from emmet.core.elasticity_legacy import ElasticityDoc
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.elasticity.query_operators import (
